Module class

Module class is used to annotate other classes that define Module.

Module a used in Karee System as an atomic part of the application. modules are a both standable alone and with the application with one entry point.

Usage


@Module(name: 'users', isRoot: true)
class UsersModule extends KareeRoutableModule {

  @override
  Future<void> initialize() async {
    await initCore(this);
    super.initialize();
  }

  @override
  bool get startWithRoot => true;

  @override
  String get path => '/users';

  @override
  String get name => 'users';

}

Constructors

Module({required String name, bool isRoot = false})
Constructor for a Module
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isRoot → bool
This flag indicate whether the module should start before the main application.
final
name → String
The name of this module. Note that this name should be the same in module routes.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited