Value class

Annotation used to read and inject value from application configuration file. located in resources/config/application.yaml

  ... in your Service or Controller classe file
  @Value('@{server.host}')
  String serverHost;
  ...

  ...
  server:
    host: https://msapi.karee.com
    security:
      type: oauth2
      ...
Annotations
  • @Target.new({TargetKind.field})

Constructors

Value(String name)
The constructor of the annotation.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the env variable in application config file (application.yaml)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited