Route class
Route: class designed to subscribe events (route) in application.
Route.on associates the event represented by the path to a specific action .
Route.on associates the event represented by the path to a specific action.
Constructors
- Route()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- defaultRouteActivation → RouteActivation
-
This function is the default Route Guard when it's not defined.
Meaning that, when you define your routes in
routes.dart, and you don't specify the activation for each route, in default case, we allow execution through this function.no setter
Static Methods
-
on(
String path, dynamic action, {RouteActivation? canActivated}) → void - This function is used to register your application in Karee Router module.