defaultRouteActivation property
RouteActivation
get
defaultRouteActivation
This function is the default Route Guard when it's not defined.
Meaning that, when you define your routes in routes.dart, and you
don't specify the activation for each route, in default case, we
allow execution through this function.
Implementation
static RouteActivation get defaultRouteActivation => (ctx) => true;