Bucket class

Bucket Widget, a new Material widget that provides you a simple and pretty way to send your main menu behind of screen. To take full advantages of this we recommend you to set a RouterWidget as his child.

Inheritance

Constructors

Bucket({required Widget child, Decoration? decoration, Widget? drawer, bool enableBucketDragGesture = true, void onBucketChange(bool)?, Key? key})
Bucket Widget, a new Material widget that provides you a simple and pretty way to send your main menu behind of screen. To take full advantages of this we recommend you to set a RouterWidget as his child.

Properties

child → Widget
child of the bucket, this widget is displayed at the top layer
final
decoration → Decoration?
decoration is used to decorate the background of the bottom layer
final
drawer → Widget?
drawer is used as the background widget shown behind the child
final
enableBucketDragGesture → bool
enableBucketDragGesture Whether this bucket should be opened or closed through the drag
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onBucketChange → void Function(bool)?
onBucketChange function triggered when the bucket is opened or closed
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → BucketState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of(BuildContext context) → BucketState?