BucketActionButton class

BucketActionButton, is used as the default button to manage event on Bucket.

Inheritance

Constructors

BucketActionButton(String? iconSemanticLabel, TextDirection? iconTextDirection, {required AnimatedIconData icon, Color? iconColor, double? iconSize, Key? key})
BucketActionButton, is used as the default button to manage event on Bucket.

Properties

hashCode → int
The hash code for this object.
no setterinherited
icon → AnimatedIconData
icon an AnimatedIconData, used when bucket changes its state.
final
iconColor → Color?
iconColor the butcket action button icon Color.
final
iconSemanticLabel → String?
iconSemanticLabel the butcket action button icon SemanticLabel.
final
iconSize → double?
iconSize the butcket action button icon Size.
final
iconTextDirection → TextDirection?
iconTextDirection the butcket action button icon TextDirection.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → BucketActionButtonState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited