restorationScopeId property
Restoration ID to save and restore the state of the application. See RestorationScope for more information.
Implementation
final String? restorationScopeId;
Restoration ID to save and restore the state of the application. See RestorationScope for more information.
final String? restorationScopeId;