RouterWidget class

RouterWidget is a widget that allows you to use internal navigation in your application.

To use this widget you need to specify the name, which is a unique symbol that references your widget router, and the initial widget displayed.

RouterWidget(
  name: #myDashboardRouter,
  initial: Center(
    child: Text('Welcome on my dashboard')
  )
)

See RoutableWidget

See RouteMode.INTERNAL

Inheritance

Constructors

RouterWidget({required Symbol name, required Widget initial})
Constructor for new Router Widget.

Properties

hashCode → int
The hash code for this object.
no setterinherited
initial → Widget
initial Refers to the initial child of this router before routing is triggered
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
name → Symbol
name The tag of this router; it's used to identify this.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → RouterWidgetState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited