StatelessComponent class abstract

StatelessComponent that is used to substitue StatelessWidget to access context outside the build function, expose also screenSize, mediaQuery and arguments

Inheritance
Annotations

Constructors

StatelessComponent({Key? key})
Constructor for StatelessComponent

Properties

arguments → dynamic
Navigation parameter
no setter
context → BuildContext
Getter: to retrieve the screen navigation context.
no setter
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mediaQuery → MediaQueryData
Getter: to retrieve the terminal mediaQuery properties.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenSize → Size
Getter: to retrieve the terminal size properties.
no setter

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
builder(BuildContext context) → Widget
see build
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited